/*! PROJECT_NAME - v1.0.12 - 2014-02-18
* http://PROJECT_WEBSITE/
* Copyright (c) 2014 OpenCB; Licensed GPLv2 */
function Pathiways(args) {
    _.extend(this, Backbone.Events);

    var _this = this;
    this.id = Utils.genId("Pathiways");

    //set default args
    this.suiteId = 22;
    this.title = 'PATH<span class="emph">i</span>WAYS';
    this.description = '';
    this.version = '1.0.12';
    this.tools = ['pathiways', 'pathiways.pathiways', 'pathiways.pathipred', 'pathiways.pathipred-prediction'];
    this.border = true;
    this.targetId;
    this.width;
    this.height;


    //set instantiation args, must be last
    _.extend(this, args);

    this.accountData = null;

    this.resizing = false;

    this.rendered = false;
    if (this.autoRender) {
        this.render();
    }
}

Pathiways.prototype = {
    render: function (targetId) {
        var _this = this;
        this.targetId = (targetId) ? targetId : this.targetId;
        if ($('#' + this.targetId).length < 1) {
            console.log('targetId not found in DOM');
            return;
        }

        console.log("Initializing Pathiways");
        this.targetDiv = $('#' + this.targetId)[0];
        this.div = $('<div id="pathiways" style="height:100%;position:relative;"></div>')[0];
        $(this.targetDiv).append(this.div);

        this.headerWidgetDiv = $('<div id="header-widget"></div>')[0];
        $(this.div).append(this.headerWidgetDiv);
        this.menuDiv = $('<div id="menu"></div>')[0];
        $(this.div).append(this.menuDiv);
        this.wrapDiv = $('<div id="wrap" style="height:100%;position:relative;"></div>')[0];
        $(this.div).append(this.wrapDiv);


        this.sidePanelDiv = $('<div id="right-side-panel" style="position:absolute; z-index:50;right:0px;"></div>')[0];
        $(this.wrapDiv).append(this.sidePanelDiv);

        this.contentDiv = $('<div id="content" style="height: 100%;"></div>')[0];
        $(this.wrapDiv).append(this.contentDiv);

        this.width = ($(this.div).width());
        this.height = ($(this.div).height());

        if (this.border) {
            var border = (_.isString(this.border)) ? this.border : '1px solid lightgray';
            $(this.div).css({border: border});
        }

        $(window).resize(function (event) {
            if (event.target == window) {
                if (!_this.resizing) {//avoid multiple resize events
                    _this.resizing = true;
                    _this.setSize($(_this.div).width(), $(_this.div).height());
                    setTimeout(function () {
                        _this.resizing = false;
                    }, 400);
                }
            }
        });

        this.rendered = true;
    },
    draw: function () {
        var _this = this;
        if (!this.rendered) {
            console.info('Pathiways is not rendered yet');
            return;
        }

        /* Header Widget */
        this.headerWidget = this._createHeaderWidget($(this.headerWidgetDiv).attr('id'));

        /* Header Widget */
        this.menu = this._createMenu($(this.menuDiv).attr('id'));

        /* check height */
        var topOffset = $(this.headerWidgetDiv).height() + $(this.menuDiv).height();
        $(this.wrapDiv).css({height: 'calc(100% - ' + topOffset + 'px)'});

        /* Wrap Panel */
        this.panel = this._createPanel($(this.contentDiv).attr('id'));

        /* Job List Widget */
        this.jobListWidget = this._createJobListWidget($(this.sidePanelDiv).attr('id'));


        this.pathiwaysForm = new PathiwaysForm(this);
        this.pathiwaysForm.draw({title: "PATHiWAYS", tabpanel: this.panel});

        this.pathipredForm = new PathipredForm(this);
        this.pathipredForm.draw({title: "PATHiPRED", tabpanel: this.panel});

        this.pathipredPredictionForm = new PathipredPredictionForm(this);
        this.pathipredPredictionForm.draw({title: "PATHiPRED-Prediction", tabpanel: this.panel});


        /*check login*/
        if ($.cookie('bioinfo_sid') != null) {
            this.sessionInitiated();
        } else {
            this.sessionFinished();
        }

    },
    _createHeaderWidget: function (targetId) {
        var _this = this;
        var headerWidget = new HeaderWidget({
            targetId: targetId,
            autoRender: true,
            appname: this.title,
            description: this.description,
            version: this.version,
            suiteId: this.suiteId,
            accountData: this.accountData,
            handlers: {
                'login': function (event) {
                    Ext.example.msg('Welcome', 'You logged in');
                    _this.sessionInitiated();
                },
                'logout': function (event) {
                    Ext.example.msg('Good bye', 'You logged out');
                    _this.sessionFinished();

                },
                'account:change': function (event) {
                    _this.setAccountData(event.response);

                }
            }
        });
        headerWidget.draw();

        return headerWidget;
    },
    _createMenu: function (targetId) {
        var _this = this;
        var toolbar = Ext.create('Ext.toolbar.Toolbar', {
            id: this.id + "navToolbar",
            renderTo: targetId,
            cls: 'gm-navigation-bar',
            region: "north",
            width: '100%',
            border: false,
            items: [
                {
                    id: this.id + "btnPathi",
//                    disabled: true,
                    text: '<span class="link emph">Press to run PATHiWAYS<span>',
                    handler: function () {
                        _this.showPathiwaysForm();
                    }
                },
                {
                    id: this.id + "btnPred",
//                    disabled: true,
                    text: '<span class="link emph">Press to run PATHiPRED<span>',
                    handler: function () {
                        _this.showPathipredForm();
                    }
                },
                '->'
                ,
                {
                    id: this.id + 'jobsButton',
                    tooltip: 'Show Jobs',
                    text: '<span class="emph"> Hide jobs </span>',
                    enableToggle: true,
                    pressed: true,
                    toggleHandler: function () {
                        if (this.pressed) {
                            this.setText('<span class="emph"> Hide jobs </span>');
                            _this.jobListWidget.show();
                        } else {
                            this.setText('<span class="emph"> Show jobs </span>');
                            _this.jobListWidget.hide();
                        }
                    }
                }
            ]
        });
        return toolbar;
    },
    _createPanel: function (targetId) {
        var _this = this;

        homePanel = Ext.create('Ext.panel.Panel', {
//            padding: 30,
//            margin: "10 0 0 0",
            title: 'Home',
//            html: suiteInfo,
            border: 0,
//			layout: {
//		        type: 'vbox',
//		        align: 'stretch'
//		    },
            items: [
                {
                    xtype: 'panel',
//                    title:'Home',
                    padding: 30,
                    border: false,
                    autoScroll: true,
                    html: SUITE_INFO,
                    bodyPadding: 30,
                    flex: 1
                },
                {
                    xtype: 'button',
                    padding: 20,
                    margin: '0 0 0 150',
                    text: 'Run PATHiWAYS',
                    handler: function () {
                        _this.showPathiwaysForm();
                    }
                },
                {
                    xtype: 'button',
                    padding: 20,
                    margin: '0 0 0 150',
                    text: 'Run PATHiPRED',
                    handler: function () {
                        _this.showPathipredForm();
                    }
                }
            ]
        });
        var panel = Ext.create('Ext.tab.Panel', {
            renderTo: targetId,
            width: '100%',
            height: '100%',
            border: 0,
            cls: 'ocb-border-top-lightgrey',
            activeTab: 0,
            items: [homePanel]
        });
        return panel;
    },
    _createJobListWidget: function (targetId) {
        var _this = this;

        var jobListWidget = new JobListWidget({
            'timeout': 4000,
            'suiteId': this.suiteId,
            'tools': this.tools,
            'pagedViewList': {
                'title': 'Jobs',
                'pageSize': 7,
                'targetId': targetId,
                'order': 0,
                'width': 280,
                'height': 625,
                border: true,
                'mode': 'view'
            }
        });

        /**Atach events i listen**/
        jobListWidget.pagedListViewWidget.on('item:click', function (data) {
            _this.jobItemClick(data.item);
        });
        jobListWidget.draw();

        return jobListWidget;
    }
}

Pathiways.prototype.sessionInitiated = function () {
    Ext.getCmp(this.id + 'jobsButton').enable();
    Ext.getCmp(this.id + 'jobsButton').toggle(true);
    //this.jobListWidget.draw();
    //this.dataListWidget.draw();
};

Pathiways.prototype.sessionFinished = function () {
    var _this = this;
    Ext.getCmp(this.id + 'jobsButton').disable();
    Ext.getCmp(this.id + 'jobsButton').toggle(false);

    this.jobListWidget.clean();
    this.accountData = null;

    this.panel.items.each(function (child) {
        if (child.title != 'Home') {
            if (child.title === 'PATHiPRED') {
                _this.pathipredForm.clean();
                _this.pathiwaysForm.clean();
            }
            child.close();
        }
    })
};

Pathiways.prototype.setAccountData = function (response) {
    this.accountData = response;
    this.jobListWidget.setAccountData(this.accountData);
};

Pathiways.prototype.setSize = function (width, height) {
    this.width = width;
    this.height = height;

    this.headerWidget.setWidth(width);
    this.menu.setWidth($(this.menuDiv).width());
    this.panel.setWidth($(this.contentDiv).width());
};

Pathiways.prototype.jobItemClick = function (record) {
    var _this = this;
    this.jobId = record.data.id;
    if (record.data.visites >= 0) {


        Ext.getCmp(this.id + 'jobsButton').toggle(false);

        var extItems = [];

        var layoutName = record.raw.toolName.split('.')[0];

        if (record.raw.toolName == 'pathiways.pathipred') {
            var buttonPrediction = Ext.create('Ext.button.Button');
            var button = Ext.create('Ext.button.Button');
            extItems.push(button);
            extItems.push(buttonPrediction);
            layoutName = record.raw.toolName.split('.')[1];
        }

        if (record.raw.toolName == 'pathiways.pathiways') {
            var button = Ext.create('Ext.button.Button');
            extItems.push(button);
        }
        if (record.raw.toolName == 'pathiways.pathipred-prediction') {
            layoutName = record.raw.toolName.split('.')[1];
        }

        var resultWidget = new ResultWidget({
            targetId: this.panel.getId(),
            application: 'pathiway',
            app: this,
            extItems: extItems,
            layoutName: layoutName
        });
        resultWidget.draw($.cookie('bioinfo_sid'), record);

        if (record.raw.toolName == 'pathiways.pathipred') {
            button.setText('<span style="color:blue;">Run PATHiWAYS</span>');
            button.on('click', function () {
                _this.showPathiwaysForm();
                _this.pathiwaysForm.loadForm(resultWidget.job);
            });
            buttonPrediction.setText('<span style="color:blue;">Apply to a new dataset</span>');
            buttonPrediction.on('click', function () {
                _this.showPathipredPredictionForm();
                _this.pathipredPredictionForm.loadForm(resultWidget.job);
            });
        } else if (record.raw.toolName == 'pathiways.pathiways') {
            button.setText('<span style="color:blue;">Run PATHiPRED</span>');
            button.on('click', function () {
                _this.showPathipredForm();
                _this.pathipredForm.loadForm(resultWidget.job);
            });
        }


        console.log(this.jobId)
        console.log(record.raw);

        /* result widget parses the commandLine on record and adds the command key */

//                    var config = {
//                        'norm-matrix': "example_GSE4107.txt",
//                        'exp-design': "example_ED_GSE4107.txt",
//                        species: "hsapiens",
//                        platform: "HGU133Plus2",
//                        'cel-compressed-file': false,
//                        test: "wilcoxon",
//                        paired: "FALSE",
//                        control: "CONTROL",
//                        disease: "CRC",
//                        jobname: "Example 1",
//                        'exp-name': "Example 1",
//                        jobdescription: "fsdafdsafdsa",
//                        summ: "max",
//                        pathways: "hsa03320",
//                        sessionid: "sBrIYTwce6Ui3YHNZHig",
//                        accountid: "fsalavert"
//                    };

    }
};


Pathiways.prototype.showPathiwaysForm = function () {
    var _this = this;
    var showForm = function () {
        if (!_this.panel.contains(_this.pathiwaysForm.panel)) {
            _this.pathiwaysForm.clean();
            _this.panel.add(_this.pathiwaysForm.panel);
        }
        _this.panel.setActiveTab(_this.pathiwaysForm.panel);
    };
    this._checkLogin(showForm);
};


Pathiways.prototype.showPathipredForm = function (config) {
    var _this = this;
    var showForm = function () {
        if (!_this.panel.contains(_this.pathipredForm.panel)) {
            _this.pathipredForm.clean();
            _this.panel.add(_this.pathipredForm.panel);
        }
        _this.panel.setActiveTab(_this.pathipredForm.panel);
    };
    this._checkLogin(showForm);
};

Pathiways.prototype.showPathipredPredictionForm = function (config) {
    if (!this.panel.contains(this.pathipredPredictionForm.panel)) {
        this.panel.add(this.pathipredPredictionForm.panel);
    }
    this.panel.setActiveTab(this.pathipredPredictionForm.panel);
};

Pathiways.prototype._checkLogin = function (showForm) {
    if (!$.cookie('bioinfo_sid')) {
        this.headerWidget.on('login', function (event) {
            showForm();
        });
        this.headerWidget.loginWidget.anonymousSign();
    } else {
        showForm();
    }
};


Pathiways.prototype.showGRNViewer = function () {
    var _this = this;
    this.viewer = Ext.getCmp(this.id + "_grnViewer");
    if (this.viewer == null) {
        //Collapse to calculate width for CellBrowser
        pan = 26;
        if (!Ext.getCmp(this.eastPanelId).isHidden() || Ext.getCmp(this.eastPanelId).collapsed) {
            Ext.getCmp(this.eastPanelId).collapse();
            pan = 0;
        }
        var cellBrowserContainer = Ext.create('Ext.container.Container', {
            id: this.id + 'contGRNViewer'
//			html:'<div id=grnViewerCellBrowser></div>'
        });

        this.viewer = Ext.create('Ext.panel.Panel', {
            id: this.id + "_grnViewer",
            border: false,
            title: "Workspace",
//		    closable:true,
            items: cellBrowserContainer
//		    autoScroll:true
        });

        Ext.getCmp(this.centerPanelId).add(this.viewer);

        //Once actived, the div element is visible, and CellBrowser can be rendered
        Ext.getCmp(this.centerPanelId).setActiveTab(this.viewer);
        this.networkViewer = new NetworkViewer(this.id + 'contGRNViewer', {
            width: this.viewer.getWidth() - (0/*15+pan*/),
            height: this.viewer.getHeight() - 0/*26*/,
            //menuBar:this.getMenuBar(),
            overview: true,
            version: '<span class="info">Cell Browser v' + this.version + '</span>'
        });
//		this.networkViewer.setSpeciesMenu(AVAILABLE_SPECIES);
        this.networkViewer.draw();

        this.nodeAttributeEditWidget = new AttributeEditWidget(this.networkViewer.getNetworkData().getNodeAttributes(), "Node");
        this.nodeAttributeFilterWidget = new AttributeFilterWidget(this.networkViewer.getNetworkData().getNodeAttributes(), "Node");

        this.edgeAttributeEditWidget = new AttributeEditWidget(this.networkViewer.getNetworkData().getEdgeAttributes(), "Edge");
        this.edgeAttributeFilterWidget = new AttributeFilterWidget(this.networkViewer.getNetworkData().getEdgeAttributes(), "Edge");

        this.networkViewer.onSelectionChange.addEventListener(function (sender, data) {
            if (Ext.getCmp("editNodeAttrWindow")) {
                _this.nodeAttributeEditWidget.selectRowsById(data);
            }
            if (Ext.getCmp("filterNodeAttrWindow")) {
                _this.nodeAttributeFilterWidget.selectRowsById(data);
            }
        });

        this.nodeAttributeEditWidget.onSelectNodes.addEventListener(function (sender, data) {
            _this.networkViewer.selectNodes(data);
        });

        this.nodeAttributeFilterWidget.onSelectNodes.addEventListener(function (sender, data) {
            _this.networkViewer.selectNodes(data);
        });

        this.nodeAttributeFilterWidget.onDeselectNodes.addEventListener(function () {
            _this.networkViewer.deselectAllNodes();
        });

        this.nodeAttributeFilterWidget.onFilterNodes.addEventListener(function (sender, data) {
            _this.networkViewer.filterNodes(data);
        });

        this.nodeAttributeFilterWidget.onRestoreNodes.addEventListener(function () {
            _this.networkViewer.refresh();
        });
    }
    else {
        Ext.getCmp(this.centerPanelId).setActiveTab(this.viewer);
    }
};


PathiwaysForm.prototype = new GenericFormPanel("pathiways.pathiways");

function PathiwaysForm(webapp) {
    this.id = Utils.genId("PathiwaysForm");
    this.headerWidget = webapp.headerWidget;
    this.opencgaBrowserWidget = webapp.headerWidget.opencgaBrowserWidget;
    this.onSelectNodes = new Event(this);
}

PathiwaysForm.prototype.beforeRun = function () {
    var pathways = [];
    var speciesPrefix = this.paramsWS["species"].substring(0, 3);
    Ext.getCmp(this.id + 'pathways').items.each(function (item) {
        if (item.getSubmitValue() != null) {
            var value = speciesPrefix + item.getSubmitValue();
            pathways.push(value);
        }

    });

    if (pathways.length > 0) this.paramsWS["pathways"] = pathways.toString();
    else this.paramsWS["pathways"] = "";
    this.paramsWS["exp-name"] = this.paramsWS["jobname"];
    //    this.testing = true;
};

PathiwaysForm.prototype.getPanels = function () {
    return [
        this._getExamplesPanel(),
        this._getSpeciesPanel(),
        this._getSelectDataPanel(),
        this._getExpDesignPanel(),
        this._getOtherParamsPanel(),
        this._getComparisonTestsPanel(),
        this._getPathwaysPanel()
    ];
};

PathiwaysForm.prototype._getExamplesPanel = function () {
    var _this = this;

    var example1 = Ext.create('Ext.Component', {
        html: '<span class="u"><span class="emph u">Load example 1.</span> <span class="info s110">Colorectal cancer</span></span>',
        cls: 'dedo',
        listeners: {
            afterrender: function () {
                this.getEl().on("click", function () {
                    _this.loadExample1();
                    Ext.example.msg("Example loaded", "");
                });
            }
        }
    });
    var example2 = Ext.create('Ext.Component', {
        html: '<span class="u"><span class="emph u">Load example 2.</span> <span class="info s110">VCF file with ~5000 variants</span></span>',
        cls: 'dedo',
        listeners: {
            afterrender: function () {
                this.getEl().on("click", function () {
                    _this.loadExample2();
                    Ext.example.msg("Example loaded", "");
                });
            }
        }
    });

    var exampleForm = Ext.create('Ext.container.Container', {
        bodyPadding: 10,
        margin: '0 0 10 0',
        defaults: {margin: '0 0 5 0'},
        items: [example1]
    });

    return exampleForm;
};

PathiwaysForm.prototype._getSpeciesPanel = function () {
    var _this = this;

    var species = Ext.create('Ext.form.RadioGroup', {
        id: this.id + 'speciesRadioGroup',
        layout: 'vbox',
        fieldLabel: 'Species',
        margin: "0 0 10 0",
        defaults: {
            name: 'species'
        },
        items: [
            {
                inputValue: 'hsapiens',
                boxLabel: 'Human (Homo sapiens)',
                checked: true,
                listeners: {change: function (cmp, value) {
                    if (value) {
                        platform.removeAll();
                        platform.add(humanItems);

                        Ext.getCmp(_this.id + 'allPathways').setValue(false);

                        Ext.getCmp('pathways04620' + _this.id).enable();

                        Ext.getCmp('pathways04340' + _this.id).enable();
                        Ext.getCmp('pathways04150' + _this.id).enable();
                        Ext.getCmp('pathways04060' + _this.id).enable();
                        Ext.getCmp('pathways04512' + _this.id).enable();
                        Ext.getCmp('pathways04115' + _this.id).enable();
                        Ext.getCmp('pathways04530' + _this.id).enable();
                        Ext.getCmp('pathways04660' + _this.id).enable();
//                        Ext.getCmp('pathways04062' + _this.id).disable();
                    }
                }}
            },
            {
                inputValue: 'mmusculus',
                boxLabel: 'Mouse (Mus musculus)',
                listeners: {change: function (cmp, value) {
                    if (value) {
                        platform.removeAll();
                        platform.add(mouseItems);

                        Ext.getCmp(_this.id + 'allPathways').setValue(false);

                        Ext.getCmp('pathways04620' + _this.id).setValue(false).disable();

                        Ext.getCmp('pathways04340' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04150' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04060' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04512' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04115' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04530' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04660' + _this.id).setValue(false).disable();
//                    Ext.getCmp('pathways04062' + _this.id).setValue(false).disable();
                    }
                }}
            }
        ]
    });

    var humanItems = [
        {
            inputValue: 'HGU133Plus2',
            boxLabel: 'Affymetrix Human Genome U133 Plus 2.0 Array',
            checked: true
        },
        {
            inputValue: 'HGU133A',
            boxLabel: 'Affymetrix Human Genome U133A Array',
            checked: false
        },
        {
            inputValue: 'HGU133A_2',
            boxLabel: 'Affymetrix Human Genome U133A 2.0 Array',
            checked: false
        }
    ];

    var mouseItems = [
        {
            inputValue: 'MoGene',
            boxLabel: 'Affymetrix Mouse Gene 1.0 ST Array',
            checked: true
        },
        {
            inputValue: 'Mouse430_2',
            boxLabel: 'Affymetrix Mouse Genome 430 2.0 Array',
            checked: false
        }
    ];

    var platform = Ext.create('Ext.form.RadioGroup', {
        id: this.id + 'platformRadioGroup',
        layout: 'vbox',
        fieldLabel: 'Platform',
        margin: "0 0 0 0",
        defaults: {
            name: 'platform'
        },
        items: humanItems
    });

    return Ext.create('Ext.panel.Panel', {
        title: 'Species',
        border: true,
        bodyPadding: "10",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
//		layout: 'hbox',
        items: [
            species,
            platform
        ]
    });
};

PathiwaysForm.prototype._getSelectDataPanel = function () {
    var _this = this;


    var createBrowser = this.createOpencgaBrowserCmp({
        fieldLabel: 'Input file:',
        dataParamName: 'norm-matrix',
        id: this.id + 'norm-matrix',
        mode: 'fileSelection',
        beforeClick: function (args) {
            if (Ext.getCmp(_this.id + 'normRadio').getValue()) {
                args.allowedTypes = ['txt'];
            } else {
                args.allowedTypes = ['cel'];
            }
        },
        allowedTypes: ['txt'],
        allowBlank: false
    });

    var items = [
        {
            id: this.id + 'compressedRadio',
            inputValue: true,
            boxLabel: 'CEL compressed file',
            checked: false
        },
        {
            id: this.id + 'normRadio',
            inputValue: false,
            boxLabel: 'Normalized matrix',
            checked: true
        }
    ];
    var matrixOrCel = Ext.create('Ext.form.RadioGroup', {
        layout: 'vbox',
        fieldLabel: 'Platform',
        margin: "0 0 0 0",
        defaults: {
            name: 'cel-compressed-file'
        },
        items: items
    });


    var panel = Ext.create('Ext.panel.Panel', {
        title: 'Select your data',
        border: true,
        bodyPadding: "5",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
        layout: 'vbox',
        items: [matrixOrCel, createBrowser]
    });

    return panel;
};

PathiwaysForm.prototype._getExpDesignPanel = function () {

    var control = Ext.create('Ext.form.field.Text', {
        id: this.id + "control",
        name: "control",
        fieldLabel: 'Condition 1',
        margin: '10 0 0 5',
        allowBlank: false
    });

    var disease = Ext.create('Ext.form.field.Text', {
        id: this.id + "disease",
        name: "disease",
        fieldLabel: 'Condition 2',
        margin: '10 0 0 5',
        allowBlank: false
    });

    return Ext.create('Ext.panel.Panel', {
        title: 'Experimental design',
        border: true,
        bodyPadding: "5",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
        layout: 'vbox',
        items: [
            this.createOpencgaBrowserCmp({
                fieldLabel: 'Experimental design data:',
                dataParamName: 'exp-design',
                id: this.id + 'exp-design',
                mode: 'fileSelection',
                allowedTypes: ['txt'],
                allowBlank: false
            }),
            control,
            disease
        ]
    });
};

PathiwaysForm.prototype._getOtherParamsPanel = function () {
    var summValues = Ext.create('Ext.data.Store', {
        id: this.id + 'summStore',
        fields: ['value', 'name'],
        data: [
            {"value": "mean", "name": "mean"},
            {"value": "median", "name": "median"},
            {"value": "max", "name": "max"},
            {"value": "min", "name": "minimum"},
            {"value": "per90", "name": "90th percentile"},
            {"value": "per95", "name": "95th percentile"},
            {"value": "per99", "name": "99th percentile"}
        ]
    });

    var summ = Ext.create('Ext.form.field.ComboBox', {
        id: this.id + "summ",
        name: "summ",
        fieldLabel: "Summ",
        store: summValues,
        queryMode: 'local',
        displayField: 'name',
        valueField: 'value',
        value: summValues.getAt(4).get('value'),
        labelWidth: 100,
        margin: '5 0 5 5',
        editable: false,
        allowBlank: false
    });

    return Ext.create('Ext.panel.Panel', {
        title: 'Other parameters',
        border: true,
        bodyPadding: "5",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
        layout: 'vbox',
        items: [summ]
    });
};

PathiwaysForm.prototype._getComparisonTestsPanel = function () {
    var tests = Ext.create('Ext.form.RadioGroup', {
        id: this.id + 'tests',
        layout: 'vbox',
        fieldLabel: 'Test',
        margin: "0 0 10 0",
        defaults: {
            name: 'test'
        },
        items: [
            {
                inputValue: 'multilevel',
                boxLabel: 'Multilevel test',
                checked: true,
                listeners: {change: function (cmp, value) {
                    if (value) {
                        paired.hide();
                        paired.setValue({'paired': 'NULL'});
                    }
                }}
            },
            {
                inputValue: 'wilcoxon',
                boxLabel: 'Wilcoxon test',
                listeners: {change: function (cmp, value) {
                    if (value) {
                        paired.show();
                        paired.setValue({'paired': 'TRUE'});
                    }
                }}
            }
        ]
    });

    var wilcoxonItems = [
        {
            inputValue: 'TRUE',
            boxLabel: 'Paired',
            checked: false
        },
        {
            inputValue: 'FALSE',
            boxLabel: 'No Paired',
            checked: false
        },
        {
            inputValue: 'NULL',
            boxLabel: 'null',
            hidden: true,
            checked: true
        }
    ];

    var paired = Ext.create('Ext.form.RadioGroup', {
        id: this.id + 'paired',
        layout: 'vbox',
        hidden: true,
        fieldLabel: ' ',
        margin: "-10 0 0 15",
        defaults: {
            name: 'paired'
        },
        items: wilcoxonItems
    });

    var panel = Ext.create('Ext.panel.Panel', {
        title: 'Comparison tests',
        border: true,
        bodyPadding: "10",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
//		layout: 'hbox',
        items: [
            tests,
            paired
        ]
    });
    return panel
};

PathiwaysForm.prototype._getPathwaysPanel = function () {
    var checkAll = function (allValue) {
        pathways.items.each(function (item) {
            if (!item.isDisabled()) {
                item.setValue(allValue.value);
            }
        });
    };

    var pathways = Ext.create('Ext.form.CheckboxGroup', {
        // Arrange checkboxes into two columns, distributed vertically
        id: this.id + 'pathways',
        columns: 2,
        vertical: true,
        defaults: {margin: '0 15 0 0'},
        items: [
            { boxLabel: 'PPAR SIGNALING PATHWAY', name: 'pathways', inputValue: '03320' },
            { boxLabel: 'ERBB SIGNALING PATHWAY', name: 'pathways', inputValue: '04012' },
            { boxLabel: 'CALCIUM SIGNALING PATHWAY', name: 'pathways', inputValue: '04020' },
            { boxLabel: 'CYTOKINE-CYTOKINE RECEPTOR', name: 'pathways', inputValue: '04060', id: 'pathways04060' + this.id},
//            { boxLabel: 'CHEMOKINE SIGNALING PATHWAY', name: 'pathways', inputValue: '04062', id: 'pathways04062' + this.id},
            { boxLabel: 'NEUROACTIVE LIGAND-RECEPTOR INTERACTION', name: 'pathways', inputValue: '04080' },
            { boxLabel: 'p53 SIGNALING PATHWAY', name: 'pathways', inputValue: '04115', id: 'pathways04115' + this.id},
            { boxLabel: 'mTOR SIGNALING PATHWAY', name: 'pathways', inputValue: '04150', id: 'pathways04150' + this.id},
            { boxLabel: 'APOPTOSIS', name: 'pathways', inputValue: '04210' },
            { boxLabel: 'WNT SIGNALING PATHWAY', name: 'pathways', inputValue: '04310' },
            { boxLabel: 'NOTCH SIGNALING PATHWAY', name: 'pathways', inputValue: '04330' },
            { boxLabel: 'HEDGEHOG SIGNALING PATHWAY', name: 'pathways', inputValue: '04340', id: 'pathways04340' + this.id},
            { boxLabel: 'VEGF SIGNALING PATHWAY', name: 'pathways', inputValue: '04370' },
            { boxLabel: 'ECM-RECEPTOR INTERACTION', name: 'pathways', inputValue: '04512', id: 'pathways04512' + this.id},
            { boxLabel: 'CELL ADHESION MOLECULES', name: 'pathways', inputValue: '04514' },
            { boxLabel: 'TIGH JUNCTION', name: 'pathways', inputValue: '04530', id: 'pathways04530' + this.id},
            { boxLabel: 'GAP JUNCTION', name: 'pathways', inputValue: '04540' },
            { boxLabel: 'ANTIGEN PROCESING AND PRESENTATION', name: 'pathways', inputValue: '04612' },
            { boxLabel: 'TOLL-LIKE RECEPTOR SIGNALING PATHWAY', name: 'pathways', inputValue: '04620', id: 'pathways04620' + this.id},
            { boxLabel: 'JAK-STAT SIGNALING PATHWAY', name: 'pathways', inputValue: '04630' },
            { boxLabel: 'T CELL RECPTOR SIGNALING PATHWAY', name: 'pathways', inputValue: '04660', id: 'pathways04660' + this.id},
            { boxLabel: 'B CELL RECEPTOR SIGNALING PATHWAY', name: 'pathways', inputValue: '04662' },
            { boxLabel: 'Fc EPSILON RI SIGNALING PATHWAY', name: 'pathways', inputValue: '04664' },
            { boxLabel: 'INSULIN SIGNALING PATHWAY', name: 'pathways', inputValue: '04910' },
            { boxLabel: 'GnRH SIGNALING PATHWAY', name: 'pathways', inputValue: '04912' },
            { boxLabel: 'MELANOGENESIS', name: 'pathways', inputValue: '04916' },
            { boxLabel: 'ADIPOCYTOKINE SIGNALING PATHWAY', name: 'pathways', inputValue: '04920' }
        ]
    });

    return Ext.create('Ext.panel.Panel', {
        title: 'Pathways',
        border: true,
        bodyPadding: "5",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
        items: [
            {xtype: 'checkboxfield', id: this.id + 'allPathways', name: 'allPathways', boxLabel: 'All', handler: checkAll, margin: '0 0 2 4', inputValue: "Funciona"},
            pathways
        ]
    });
};


PathiwaysForm.prototype.loadForm = function (job) {
    var command = job.command.data;
    if (command) {

        var pathToRemove = '/httpd/bioinfo/opencga/accounts/' + $.cookie("bioinfo_account") + '/';
        command['norm-matrix'] = command['norm-matrix'].replace(pathToRemove, '');
        command['exp-design'] = command['exp-design'].replace(pathToRemove, '');

        if (command['norm-matrix'].indexOf('/opencga/analysis/pathiways/examples/') != -1) {
            var arr = command['norm-matrix'].split(/\//g);
            command['norm-matrix'] = 'example_' + arr[arr.length - 1];
        }
        if (command['exp-design'].indexOf('/opencga/analysis/pathiways/examples/') != -1) {
            var arr = command['exp-design'].split(/\//g);
            command['exp-design'] = 'example_' + arr[arr.length - 1];
        }

        Ext.getCmp(this.id + 'norm-matrix').setText('<span class="emph">' + command['norm-matrix'] + '</span>', false);
        Ext.getCmp(this.id + 'norm-matrix' + 'hidden').setValue(command['norm-matrix'].replace(/\//g, ":"));

        Ext.getCmp(this.id + 'exp-design').setText('<span class="emph">' + command['exp-design'] + '</span>', false);
        Ext.getCmp(this.id + 'exp-design' + 'hidden').setValue(command['exp-design'].replace(/\//g, ":"));


        Ext.getCmp(this.id + 'platformRadioGroup').setValue({platform: command['platform']});

        if (command['cel-compressed-file'] == 'true') {
            Ext.getCmp(this.id + 'compressedRadio').setValue(true);
        } else {
            Ext.getCmp(this.id + 'normRadio').setValue(true);
        }


        Ext.getCmp(this.id + 'control').setValue(command['control']);
        Ext.getCmp(this.id + 'disease').setValue(command['disease']);


        Ext.getCmp(this.id + 'summ').select(Ext.getStore(this.id + 'summStore').findRecord('value', command['summ']));


        Ext.getCmp(this.id + 'allPathways').setValue(false);
        /* process pathways */
        var pathways_array = command['pathways'].replace('/ /g', '').split(/,{1}/g);
        for (var i = 0; i < pathways_array.length; i++) {
            var pathway_code = pathways_array[i].substring(3);
            Ext.getCmp(this.id + 'pathways').child('checkboxfield[inputValue=' + pathway_code + ']').setValue(true);
        }

        var species;
        if (pathways_array[0].substring(0, 3) == 'hsa') {
            species = 'hsapiens'
        }
        if (pathways_array[0].substring(0, 3) == 'mmu') {
            species = 'mmusculus'
        }
        Ext.getCmp(this.id + 'speciesRadioGroup').setValue({species: species});
        /* */


        Ext.getCmp(this.id + 'jobname').setValue(command['exp-name']);
        Ext.getCmp(this.id + 'jobdescription').setValue(command['jobdescription']);
    }

};


PathiwaysForm.prototype.loadExample1 = function () {
    Ext.getCmp(this.id + 'norm-matrix').setText('<span class="emph">Example colorectal cancer</span>', false);
    Ext.getCmp(this.id + 'norm-matrix' + 'hidden').setValue('example_GSE4107.txt');

    Ext.getCmp(this.id + 'exp-design').setText('<span class="emph">Example colorectal cancer</span>', false);
    Ext.getCmp(this.id + 'exp-design' + 'hidden').setValue('example_ED_GSE4107.txt');

    Ext.getCmp(this.id + 'speciesRadioGroup').setValue({species: 'hsapiens'});
    Ext.getCmp(this.id + 'normRadio').setValue(true);

    Ext.getCmp(this.id + 'control').setValue("CONTROL");
    Ext.getCmp(this.id + 'disease').setValue("CRC");
    Ext.getCmp(this.id + 'allPathways').setValue(true);

    Ext.getCmp(this.id + 'jobname').setValue("Example 1");
    Ext.getCmp(this.id + 'jobdescription').setValue("Colorectal cancer");
};


PathiwaysForm.prototype.clean = function () {
    Ext.getCmp(this.id + 'speciesRadioGroup').setValue({species: 'hsapiens'});
    Ext.getCmp(this.id + 'platformRadioGroup').setValue({platform:'HGU133Plus2'});

    Ext.getCmp(this.id + 'normRadio').setValue(true);

    Ext.getCmp(this.id + 'norm-matrix').setText('<span class="emph">No file selected</span>', false);
    Ext.getCmp(this.id + 'norm-matrix' + 'hidden').setValue('');

    Ext.getCmp(this.id + 'exp-design').setText('<span class="emph">No file selected</span>', false);
    Ext.getCmp(this.id + 'exp-design' + 'hidden').setValue('');

    Ext.getCmp(this.id + 'control').setValue('');
    Ext.getCmp(this.id + 'disease').setValue('');

    Ext.getCmp(this.id + 'summ').select(Ext.getStore(this.id + 'summStore').findRecord('value', 'per90'));

    Ext.getCmp(this.id + 'tests').setValue({test: 'multilevel'});

    Ext.getCmp(this.id + 'allPathways').setValue(true);
    Ext.getCmp(this.id + 'allPathways').setValue(false);

    Ext.getCmp(this.id + 'jobname').setValue("");
    Ext.getCmp(this.id + 'jobdescription').setValue("");
}
PathipredForm.prototype = new GenericFormPanel("pathiways.pathipred");

function PathipredForm(webapp) {
    this.id = Utils.genId("PathipredForm");
    this.headerWidget = webapp.headerWidget;
    this.opencgaBrowserWidget = webapp.headerWidget.opencgaBrowserWidget;
    this.onSelectNodes = new Event(this);
}

PathipredForm.prototype.beforeRun = function () {
    var pathways = [];
    var speciesPrefix = this.paramsWS["species"].substring(0, 3);
    Ext.getCmp(this.id + 'pathways').items.each(function (item) {
        if (item.getSubmitValue() != null) {
            var value = speciesPrefix + item.getSubmitValue();
            pathways.push(value);
        }

    });

    if (pathways.length > 0) this.paramsWS["pathways"] = pathways.toString();
    else this.paramsWS["pathways"] = "";
    this.paramsWS["exp-name"] = this.paramsWS["jobname"];
//    this.testing = true;
};

PathipredForm.prototype.getPanels = function () {
    return [
        this._getExamplesPanel(),
        this._getSpeciesPanel(),
        this._getSelectDataPanel(),
        this._getExpDesignPanel(),
        this._getOtherParamsPanel(),
        this._getPathwaysPanel()
    ];

};

PathipredForm.prototype._getExamplesPanel = function () {
    var _this = this;

    var example1 = Ext.create('Ext.Component', {
        html: '<span class="u"><span class="emph u">Load example 1.</span> <span class="info s110">Breast cancer</span></span>',
        cls: 'dedo',
        listeners: {
            afterrender: function () {
                this.getEl().on("click", function () {
                    _this.loadExample1();
                    Ext.example.msg("Example loaded", "");
                });
            }
        }
    });

    var exampleForm = Ext.create('Ext.container.Container', {
        bodyPadding: 10,
        margin: '0 0 10 0',
        defaults: {margin: '0 0 5 0'},
        items: [example1]
    });

    return exampleForm;

};
PathipredForm.prototype._getSpeciesPanel = function () {
    var _this = this;

    var species = Ext.create('Ext.form.RadioGroup', {
        id: this.id + 'speciesRadioGroup',
        layout: 'vbox',
        fieldLabel: 'Species',
        margin: "0 0 10 0",
        defaults: {
            name: 'species'
        },
        items: [
            {
                inputValue: 'hsapiens',
                boxLabel: 'Human (Homo sapiens)',
                checked: true,
                listeners: {change: function (cmp, value) {
                    if (value) {
                        platform.removeAll();
                        platform.add(humanItems);

                        Ext.getCmp(_this.id + 'allPathways').setValue(false);

                        Ext.getCmp('pathways04620' + _this.id).enable();

                        Ext.getCmp('pathways04340' + _this.id).enable();
                        Ext.getCmp('pathways04150' + _this.id).enable();
                        Ext.getCmp('pathways04060' + _this.id).enable();
                        Ext.getCmp('pathways04512' + _this.id).enable();
                        Ext.getCmp('pathways04115' + _this.id).enable();
                        Ext.getCmp('pathways04530' + _this.id).enable();
                        Ext.getCmp('pathways04660' + _this.id).enable();
//                        Ext.getCmp('pathways04062' + _this.id).disable();
                    }
                }}
            },
            {
                inputValue: 'mmusculus',
                boxLabel: 'Mouse (Mus musculus)',
                listeners: {change: function (cmp, value) {
                    if (value) {
                        platform.removeAll();
                        platform.add(mouseItems);

                        Ext.getCmp(_this.id + 'allPathways').setValue(false);

                        Ext.getCmp('pathways04620' + _this.id).setValue(false).disable();

                        Ext.getCmp('pathways04340' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04150' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04060' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04512' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04115' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04530' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04660' + _this.id).setValue(false).disable();
//                    Ext.getCmp('pathways04062' + _this.id).setValue(false).disable();
                    }
                }}
            }
        ]
    });

    var humanItems = [
        {
            inputValue: 'HGU133Plus2',
            boxLabel: 'Affymetrix Human Genome U133 Plus 2.0 Array',
            checked: true
        },
        {
            inputValue: 'HGU133A',
            boxLabel: 'Affymetrix Human Genome U133A Array',
            checked: false
        },
        {
            inputValue: 'HGU133A_2',
            boxLabel: 'Affymetrix Human Genome U133A 2.0 Array',
            checked: false
        }
    ];

    var mouseItems = [
        {
            inputValue: 'MoGene',
            boxLabel: 'Affymetrix Mouse Gene 1.0 ST Array',
            checked: true
        },
        {
            inputValue: 'Mouse430_2',
            boxLabel: 'Affymetrix Mouse Genome 430 2.0 Array',
            checked: false
        }
    ];

    var platform = Ext.create('Ext.form.RadioGroup', {
        id: this.id + 'platformRadioGroup',
        layout: 'vbox',
        fieldLabel: 'Platform',
        margin: "0 0 0 0",
        defaults: {
            name: 'platform'
        },
        items: humanItems
    });

    return Ext.create('Ext.panel.Panel', {
        title: 'Species',
        border: true,
        bodyPadding: "10",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
//		layout: 'hbox',
        items: [
            species,
            platform
        ]
    });
};

PathipredForm.prototype._getSelectDataPanel = function () {
    var _this = this;


    var createBrowser = this.createOpencgaBrowserCmp({
        fieldLabel: 'Input file:',
        dataParamName: 'norm-matrix',
        id: this.id + 'norm-matrix',
        mode: 'fileSelection',
        beforeClick: function (args) {
            if (Ext.getCmp(_this.id + 'normRadio').getValue()) {
                args.allowedTypes = ['txt'];
            } else {
                args.allowedTypes = ['cel'];
            }
        },
        allowedTypes: ['txt'],
        allowBlank: false
    });

    var items = [
        {
            id: this.id + 'compressedRadio',
            inputValue: true,
            boxLabel: 'CEL compressed file',
            checked: false
        },
        {
            id: this.id + 'normRadio',
            inputValue: false,
            boxLabel: 'Normalized matrix',
            checked: true
        }
    ];
    var matrixOrCel = Ext.create('Ext.form.RadioGroup', {
        layout: 'vbox',
        fieldLabel: 'Platform',
        margin: "0 0 0 0",
        defaults: {
            name: 'cel-compressed-file'
        },
        items: items
    });


    var panel = Ext.create('Ext.panel.Panel', {
        title: 'Select your data',
        border: true,
        bodyPadding: "5",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
        layout: 'vbox',
        items: [matrixOrCel, createBrowser]
    });

    return panel;
};

PathipredForm.prototype._getExpDesignPanel = function () {

    var control = Ext.create('Ext.form.field.Text', {
        id: this.id + "control",
        name: "control",
        fieldLabel: 'Condition 1',
        margin: '10 0 0 5',
        allowBlank: false
    });

    var disease = Ext.create('Ext.form.field.Text', {
        id: this.id + "disease",
        name: "disease",
        fieldLabel: 'Condition 2',
        margin: '10 0 0 5',
        allowBlank: false
    });

    var items = [
        {
            id: this.id + 'categoricalRadio',
            inputValue: 'categorical',
            boxLabel: 'Categorical',
            checked: true,
            listeners: {change: function (cmp, value) {
                if (value) {
                    control.show();
                    control.setValue('');
                    disease.show();
                    disease.setValue('');
                }
            }}
        },
        {
            id: this.id + 'numericalRadio',
            inputValue: 'continuous',
            boxLabel: 'Continuous',
            checked: false,
            listeners: {change: function (cmp, value) {
                if (value) {
                    control.hide();
                    control.setValue('na');
                    disease.hide();
                    disease.setValue('na');
                }
            }}
        }
    ];
    var expdesigntypeGroup = Ext.create('Ext.form.RadioGroup', {
        id: this.id + 'expdesigntype',
        layout: 'vbox',
        fieldLabel: 'Exp. design type',
        margin: "0 0 0 0",
        defaults: {
            name: 'expdesigntype'
        },
        items: items
    });

    return Ext.create('Ext.panel.Panel', {
        title: 'Experimental design',
        border: true,
        bodyPadding: "5",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
        layout: 'vbox',
        items: [
            this.createOpencgaBrowserCmp({
                fieldLabel: 'Experimental design data:',
                dataParamName: 'exp-design',
                id: this.id + 'exp-design',
                mode: 'fileSelection',
                allowedTypes: ['txt'],
                allowBlank: false
            }),
            expdesigntypeGroup,
            control,
            disease
        ]
    });
};

PathipredForm.prototype._getOtherParamsPanel = function () {
    var summValues = Ext.create('Ext.data.Store', {
        id: this.id + 'summStore',
        fields: ['value', 'name'],
        data: [
            {"value": "mean", "name": "mean"},
            {"value": "median", "name": "median"},
            {"value": "max", "name": "max"},
            {"value": "min", "name": "minimum"},
            {"value": "per90", "name": "90th percentile"},
            {"value": "per95", "name": "95th percentile"},
            {"value": "per99", "name": "99th percentile"}
        ]
    });

    var summ = Ext.create('Ext.form.field.ComboBox', {
        id: this.id + "summ",
        name: "summ",
        fieldLabel: "Summ",
        store: summValues,
        queryMode: 'local',
        displayField: 'name',
        valueField: 'value',
        value: summValues.getAt(4).get('value'),
        labelWidth: 100,
        margin: '5 0 5 5',
        editable: false,
        allowBlank: false
    });


    var kfold = Ext.create('Ext.form.field.Number', {
        id: this.id + "kfold",
        name: "k",
        fieldLabel: 'K-fold',
        margin: '10 0 0 5',
        value: 10,
        minValue: 1,
        allowBlank: false
    });

    return Ext.create('Ext.panel.Panel', {
        title: 'Other parameters',
        border: true,
        bodyPadding: "5",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
        layout: 'vbox',
        items: [summ, kfold]
    });
};

PathipredForm.prototype._getOtherParamsPanel = function () {
    var summValues = Ext.create('Ext.data.Store', {
        id: this.id + 'summStore',
        fields: ['value', 'name'],
        data: [
            {"value": "mean", "name": "mean"},
            {"value": "median", "name": "median"},
            {"value": "max", "name": "max"},
            {"value": "min", "name": "minimum"},
            {"value": "per90", "name": "90th percentile"},
            {"value": "per95", "name": "95th percentile"},
            {"value": "per99", "name": "99th percentile"}
        ]
    });

    var predictionMethodStore = Ext.create('Ext.data.Store', {
        id: this.id + 'predictionMethodStore',
        fields: ['value', 'name'],
        data: [
            {"value": "model", "name": "Best model"},
            {"value": "prior", "name": "Mechanism-based biomarkers prioritization"}
        ]
    });

    var summ = Ext.create('Ext.form.field.ComboBox', {
        id: this.id + "summ",
        name: "summ",
        fieldLabel: "Summ",
        store: summValues,
        queryMode: 'local',
        displayField: 'name',
        valueField: 'value',
        value: summValues.getAt(4).get('value'),
        labelWidth: 100,
        margin: '5 0 5 5',
        editable: false,
        allowBlank: false
    });


    var kfold = Ext.create('Ext.form.field.Number', {
        id: this.id + "kfold",
        name: "k",
        fieldLabel: 'K-fold',
        margin: '10 0 0 5',
        value: 10,
        minValue: 1,
        allowBlank: false
    });


    var predictionMethodCombo = Ext.create('Ext.form.field.ComboBox', {
        id: this.id + "predictionMethodCombo",
        name: "predmethod",
        fieldLabel: "Prediction method",
        store: predictionMethodStore,
        queryMode: 'local',
        displayField: 'name',
        valueField: 'value',
        value: predictionMethodStore.getAt(0).get('value'),
        labelWidth: 100,
        width: 400,
        margin: '5 0 5 5',
        editable: false,
        allowBlank: false
    });


    return Ext.create('Ext.panel.Panel', {
        title: 'Other parameters',
        border: true,
        bodyPadding: "5",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
        layout: 'vbox',
        items: [summ, kfold,predictionMethodCombo]
    });
};


PathipredForm.prototype._getPathwaysPanel = function () {
    var checkAll = function (allValue) {
        pathways.items.each(function (item) {
            if (!item.isDisabled()) {
                item.setValue(allValue.value);
            }
        });
    };

    var pathways = Ext.create('Ext.form.CheckboxGroup', {
        // Arrange checkboxes into two columns, distributed vertically
        id: this.id + 'pathways',
        columns: 2,
        vertical: true,
        defaults: {margin: '0 15 0 0'},
        items: [
            { boxLabel: 'PPAR SIGNALING PATHWAY', name: 'pathways', inputValue: '03320' },
            { boxLabel: 'ERBB SIGNALING PATHWAY', name: 'pathways', inputValue: '04012' },
            { boxLabel: 'CALCIUM SIGNALING PATHWAY', name: 'pathways', inputValue: '04020' },
            { boxLabel: 'CYTOKINE-CYTOKINE RECEPTOR', name: 'pathways', inputValue: '04060', id: 'pathways04060' + this.id},
//            { boxLabel: 'CHEMOKINE SIGNALING PATHWAY', name: 'pathways', inputValue: '04062', id: 'pathways04062' + this.id},
            { boxLabel: 'NEUROACTIVE LIGAND-RECEPTOR INTERACTION', name: 'pathways', inputValue: '04080' },
            { boxLabel: 'p53 SIGNALING PATHWAY', name: 'pathways', inputValue: '04115', id: 'pathways04115' + this.id},
            { boxLabel: 'mTOR SIGNALING PATHWAY', name: 'pathways', inputValue: '04150', id: 'pathways04150' + this.id},
            { boxLabel: 'APOPTOSIS', name: 'pathways', inputValue: '04210' },
            { boxLabel: 'WNT SIGNALING PATHWAY', name: 'pathways', inputValue: '04310' },
            { boxLabel: 'NOTCH SIGNALING PATHWAY', name: 'pathways', inputValue: '04330' },
            { boxLabel: 'HEDGEHOG SIGNALING PATHWAY', name: 'pathways', inputValue: '04340', id: 'pathways04340' + this.id},
            { boxLabel: 'VEGF SIGNALING PATHWAY', name: 'pathways', inputValue: '04370' },
            { boxLabel: 'ECM-RECEPTOR INTERACTION', name: 'pathways', inputValue: '04512', id: 'pathways04512' + this.id},
            { boxLabel: 'CELL ADHESION MOLECULES', name: 'pathways', inputValue: '04514' },
            { boxLabel: 'TIGH JUNCTION', name: 'pathways', inputValue: '04530', id: 'pathways04530' + this.id},
            { boxLabel: 'GAP JUNCTION', name: 'pathways', inputValue: '04540' },
            { boxLabel: 'ANTIGEN PROCESING AND PRESENTATION', name: 'pathways', inputValue: '04612' },
            { boxLabel: 'TOLL-LIKE RECEPTOR SIGNALING PATHWAY', name: 'pathways', inputValue: '04620', id: 'pathways04620' + this.id},
            { boxLabel: 'JAK-STAT SIGNALING PATHWAY', name: 'pathways', inputValue: '04630' },
            { boxLabel: 'T CELL RECPTOR SIGNALING PATHWAY', name: 'pathways', inputValue: '04660', id: 'pathways04660' + this.id},
            { boxLabel: 'B CELL RECEPTOR SIGNALING PATHWAY', name: 'pathways', inputValue: '04662' },
            { boxLabel: 'Fc EPSILON RI SIGNALING PATHWAY', name: 'pathways', inputValue: '04664' },
            { boxLabel: 'INSULIN SIGNALING PATHWAY', name: 'pathways', inputValue: '04910' },
            { boxLabel: 'GnRH SIGNALING PATHWAY', name: 'pathways', inputValue: '04912' },
            { boxLabel: 'MELANOGENESIS', name: 'pathways', inputValue: '04916' },
            { boxLabel: 'ADIPOCYTOKINE SIGNALING PATHWAY', name: 'pathways', inputValue: '04920' }
        ]
    });

    return Ext.create('Ext.panel.Panel', {
        title: 'Pathways',
        border: true,
        bodyPadding: "5",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
        items: [
            {xtype: 'checkboxfield', id: this.id + 'allPathways', name: 'allPathways', boxLabel: 'All', handler: checkAll, margin: '0 0 2 4', inputValue: "Funciona"},
            pathways
        ]
    });
};

PathipredForm.prototype.loadForm = function (job) {
    var command = job.command.data;
    if (command) {

        var pathToRemove = '/httpd/bioinfo/opencga/accounts/'+$.cookie("bioinfo_account")+'/';
        command['norm-matrix'] = command['norm-matrix'].replace(pathToRemove, '');
        command['exp-design'] = command['exp-design'].replace(pathToRemove, '');

        if (command['norm-matrix'].indexOf('/opencga/analysis/pathiways/examples/') != -1) {
            var arr = command['norm-matrix'].split(/\//g);
            command['norm-matrix'] = 'example_' + arr[arr.length - 1];
        }
        if (command['exp-design'].indexOf('/opencga/analysis/pathiways/examples/') != -1) {
            var arr = command['exp-design'].split(/\//g);
            command['exp-design'] = 'example_' + arr[arr.length - 1];
        }

        Ext.getCmp(this.id + 'norm-matrix').setText('<span class="emph">' + command['norm-matrix'] + '</span>', false);
        Ext.getCmp(this.id + 'norm-matrix' + 'hidden').setValue(command['norm-matrix'].replace(/\//g, ":"));

        Ext.getCmp(this.id + 'exp-design').setText('<span class="emph">' + command['exp-design'] + '</span>', false);
        Ext.getCmp(this.id + 'exp-design' + 'hidden').setValue(command['exp-design'].replace(/\//g, ":"));

        Ext.getCmp(this.id + 'platformRadioGroup').setValue({platform: command['platform']});

        if (command['cel-compressed-file'] == 'true') {
            Ext.getCmp(this.id + 'compressedRadio').setValue(true);
        } else {
            Ext.getCmp(this.id + 'normRadio').setValue(true);
        }


        Ext.getCmp(this.id + 'control').setValue(command['control']);
        Ext.getCmp(this.id + 'disease').setValue(command['disease']);


        Ext.getCmp(this.id + 'summ').select(Ext.getStore(this.id + 'summStore').findRecord('value', command['summ']));


        Ext.getCmp(this.id + 'allPathways').setValue(false);
        /* process pathways */
        var pathways_array = command['pathways'].replace('/ /g', '').split(/,{1}/g);
        for (var i = 0; i < pathways_array.length; i++) {
            var pathway_code = pathways_array[i].substring(3);
            Ext.getCmp(this.id + 'pathways').child('checkboxfield[inputValue=' + pathway_code + ']').setValue(true);
        }

        var species;
        if (pathways_array[0].substring(0, 3) == 'hsa') {
            species = 'hsapiens'
        }
        if (pathways_array[0].substring(0, 3) == 'mmu') {
            species = 'mmusculus'
        }
        Ext.getCmp(this.id + 'speciesRadioGroup').setValue({species: species});
        /* */


        Ext.getCmp(this.id + 'jobname').setValue(command['exp-name']);
        Ext.getCmp(this.id + 'jobdescription').setValue(command['jobdescription']);
    }

};

PathipredForm.prototype.loadExample1 = function () {
    Ext.getCmp(this.id + 'speciesRadioGroup').setValue({species: 'hsapiens'});
    Ext.getCmp(this.id + 'platformRadioGroup').setValue({platform:'HGU133Plus2'});

    Ext.getCmp(this.id + 'normRadio').setValue(true);

    Ext.getCmp(this.id + 'norm-matrix').setText('<span class="emph">Example breast cancer</span>', false);
    Ext.getCmp(this.id + 'norm-matrix' + 'hidden').setValue('example_GSE27562.txt');

    Ext.getCmp(this.id + 'exp-design').setText('<span class="emph">Example breast cancer</span>', false);
    Ext.getCmp(this.id + 'exp-design' + 'hidden').setValue('example_ED_GSE27562.txt');


    Ext.getCmp(this.id + 'expdesigntype').setValue({expdesigntype: 'categorical'});


    Ext.getCmp(this.id + 'control').setValue("normal");
    Ext.getCmp(this.id + 'disease').setValue("malignant");
    Ext.getCmp(this.id + 'allPathways').setValue(true);

    Ext.getCmp(this.id + 'summ').select(Ext.getStore(this.id + 'summStore').findRecord('value', 'per90'));
    Ext.getCmp(this.id + 'kfold').setValue(10);

    Ext.getCmp(this.id + 'jobname').setValue("Example 1");
    Ext.getCmp(this.id + 'jobdescription').setValue("Breast cancer");

};

PathipredForm.prototype.clean = function () {
    Ext.getCmp(this.id + 'speciesRadioGroup').setValue({species: 'hsapiens'});
    Ext.getCmp(this.id + 'platformRadioGroup').setValue({platform:'HGU133Plus2'});

    Ext.getCmp(this.id + 'normRadio').setValue(true);

    Ext.getCmp(this.id + 'norm-matrix').setText('<span class="emph">No file selected</span>', false);
    Ext.getCmp(this.id + 'norm-matrix' + 'hidden').setValue('');

    Ext.getCmp(this.id + 'exp-design').setText('<span class="emph">No file selected</span>', false);
    Ext.getCmp(this.id + 'exp-design' + 'hidden').setValue('');

    Ext.getCmp(this.id + 'expdesigntype').setValue({expdesigntype: 'categorical'});

    Ext.getCmp(this.id + 'control').setValue('');
    Ext.getCmp(this.id + 'disease').setValue('');

    Ext.getCmp(this.id + 'summ').select(Ext.getStore(this.id + 'summStore').findRecord('value', 'per90'));
    Ext.getCmp(this.id + 'kfold').setValue(10);

    Ext.getCmp(this.id + 'allPathways').setValue(true);
    Ext.getCmp(this.id + 'allPathways').setValue(false);


    Ext.getCmp(this.id + 'jobname').setValue("");
    Ext.getCmp(this.id + 'jobdescription').setValue("");

}
PathipredPredictionForm.prototype = new GenericFormPanel("pathiways.pathipred-prediction");

function PathipredPredictionForm(webapp) {
    this.id = Utils.genId("PathipredPredictionForm");
    this.headerWidget = webapp.headerWidget;
    this.opencgaBrowserWidget = webapp.headerWidget.opencgaBrowserWidget;
    this.onSelectNodes = new Event(this);
}

PathipredPredictionForm.prototype.beforeRun = function () {
    var pathways = [];
    var speciesPrefix = this.paramsWS["species"].substring(0, 3);
    Ext.getCmp(this.id + 'pathways').items.each(function (item) {
        if (item.getSubmitValue() != null) {
            var value = speciesPrefix + item.getSubmitValue();
            pathways.push(value);
        }

    });

    if (pathways.length > 0) this.paramsWS["pathways"] = pathways.toString();
    else this.paramsWS["pathways"] = "";
    this.paramsWS["exp-name"] = this.paramsWS["jobname"];
//    this.testing = true;
};

PathipredPredictionForm.prototype.getPanels = function () {
    return [
        this._getSpeciesPanel(),
        this._getSelectDataPanel(),
        this._getExpDesignPanel(),
        this._getOtherParamsPanel(),
        this._getPathwaysPanel()
    ];

};


PathipredPredictionForm.prototype._getSpeciesPanel = function () {
    var _this = this;

    var species = Ext.create('Ext.form.RadioGroup', {
        id: this.id + 'speciesRadioGroup',
        layout: 'vbox',
        fieldLabel: 'Species',
        margin: "0 0 10 0",
        defaults: {
            name: 'species'
        },
        items: [
            {
                inputValue: 'hsapiens',
                boxLabel: 'Human (Homo sapiens)',
                checked: true,
                listeners: {change: function (cmp, value) {
                    if (value) {
                        platform.removeAll();
                        platform.add(humanItems);

                        Ext.getCmp(_this.id + 'allPathways').setValue(false);

                        Ext.getCmp('pathways04620' + _this.id).enable();

                        Ext.getCmp('pathways04340' + _this.id).enable();
                        Ext.getCmp('pathways04150' + _this.id).enable();
                        Ext.getCmp('pathways04060' + _this.id).enable();
                        Ext.getCmp('pathways04512' + _this.id).enable();
                        Ext.getCmp('pathways04115' + _this.id).enable();
                        Ext.getCmp('pathways04530' + _this.id).enable();
                        Ext.getCmp('pathways04660' + _this.id).enable();
//                        Ext.getCmp('pathways04062' + _this.id).disable();
                    }
                }}
            },
            {
                inputValue: 'mmusculus',
                boxLabel: 'Mouse (Mus musculus)',
                listeners: {change: function (cmp, value) {
                    if (value) {
                        platform.removeAll();
                        platform.add(mouseItems);

                        Ext.getCmp(_this.id + 'allPathways').setValue(false);

                        Ext.getCmp('pathways04620' + _this.id).setValue(false).disable();

                        Ext.getCmp('pathways04340' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04150' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04060' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04512' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04115' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04530' + _this.id).setValue(false).disable();
                        Ext.getCmp('pathways04660' + _this.id).setValue(false).disable();
//                    Ext.getCmp('pathways04062' + _this.id).setValue(false).disable();
                    }
                }}
            }
        ]
    });

    var humanItems = [
        {
            inputValue: 'HGU133Plus2',
            boxLabel: 'Affymetrix Human Genome U133 Plus 2.0 Array',
            checked: true
        },
        {
            inputValue: 'HGU133A',
            boxLabel: 'Affymetrix Human Genome U133A Array',
            checked: false
        },
        {
            inputValue: 'HGU133A_2',
            boxLabel: 'Affymetrix Human Genome U133A 2.0 Array',
            checked: false
        }
    ];

    var mouseItems = [
        {
            inputValue: 'MoGene',
            boxLabel: 'Affymetrix Mouse Gene 1.0 ST Array',
            checked: true
        },
        {
            inputValue: 'Mouse430_2',
            boxLabel: 'Affymetrix Mouse Genome 430 2.0 Array',
            checked: false
        }
    ];

    var platform = Ext.create('Ext.form.RadioGroup', {
        id: this.id + 'platformRadioGroup',
        layout: 'vbox',
        fieldLabel: 'Platform',
        margin: "0 0 0 0",
        defaults: {
            name: 'platform'
        },
        items: humanItems
    });

    return Ext.create('Ext.panel.Panel', {
        title: 'Species',
        border: true,
        bodyPadding: "10",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
//		layout: 'hbox',
        items: [
            species,
            platform
        ]
    });
};

PathipredPredictionForm.prototype._getSelectDataPanel = function () {
    var _this = this;


    var createBrowser = this.createOpencgaBrowserCmp({
        fieldLabel: 'Input file:',
        dataParamName: 'norm-matrix',
        id: this.id + 'norm-matrix',
        mode: 'fileSelection',
        beforeClick: function (args) {
            if (Ext.getCmp(_this.id + 'normRadio').getValue()) {
                args.allowedTypes = ['txt'];
            } else {
                args.allowedTypes = ['cel'];
            }
        },
        allowedTypes: ['txt'],
        allowBlank: false
    });

    var items = [
        {
            id: this.id + 'compressedRadio',
            inputValue: true,
            boxLabel: 'CEL compressed file',
            checked: false
        },
        {
            id: this.id + 'normRadio',
            inputValue: false,
            boxLabel: 'Normalized matrix',
            checked: true
        }
    ];
    var matrixOrCel = Ext.create('Ext.form.RadioGroup', {
        layout: 'vbox',
        fieldLabel: 'Platform',
        margin: "0 0 0 0",
        defaults: {
            name: 'cel-compressed-file'
        },
        items: items
    });


    var panel = Ext.create('Ext.panel.Panel', {
        title: 'Select your data',
        border: true,
        bodyPadding: "5",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
        layout: 'vbox',
        items: [matrixOrCel, createBrowser]
    });

    return panel;
};

PathipredPredictionForm.prototype._getExpDesignPanel = function () {

    var control = Ext.create('Ext.form.field.Text', {
        id: this.id + "control",
        name: "control",
        fieldLabel: 'Condition 1',
        margin: '10 0 0 5',
        allowBlank: false
    });

    var disease = Ext.create('Ext.form.field.Text', {
        id: this.id + "disease",
        name: "disease",
        fieldLabel: 'Condition 2',
        margin: '10 0 0 5',
        allowBlank: false
    });

    var items = [
        {
            id: this.id + 'categoricalRadio',
            inputValue: 'categorical',
            boxLabel: 'Categorical',
            checked: true,
            listeners: {change: function (cmp, value) {
                if (value) {
                    control.show();
                    control.setValue('');
                    disease.show();
                    disease.setValue('');
                }
            }}
        },
        {
            id: this.id + 'numericalRadio',
            inputValue: 'numerical',
            boxLabel: 'Numerical',
            checked: false,
            listeners: {change: function (cmp, value) {
                if (value) {
                    control.hide();
                    control.setValue('na');
                    disease.hide();
                    disease.setValue('na');
                }
            }}
        }
    ];
    var expdesigntypeGroup = Ext.create('Ext.form.RadioGroup', {
        id: this.id + 'expdesigntype',
        layout: 'vbox',
        fieldLabel: 'Exp. design type',
        margin: "0 0 0 0",
        defaults: {
            name: 'expdesigntype'
        },
        items: items
    });

    return Ext.create('Ext.panel.Panel', {
        title: 'Experimental design',
        border: true,
        bodyPadding: "5",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
        layout: 'vbox',
        items: [
            this.createOpencgaBrowserCmp({
                fieldLabel: 'Experimental design data:',
                dataParamName: 'exp-design',
                id: this.id + 'exp-design',
                mode: 'fileSelection',
                allowedTypes: ['txt'],
                allowBlank: false
            }),
            expdesigntypeGroup,
            control,
            disease
        ]
    });
};

PathipredPredictionForm.prototype._getOtherParamsPanel = function () {
    var summValues = Ext.create('Ext.data.Store', {
        id: this.id + 'summStore',
        fields: ['value', 'name'],
        data: [
            {"value": "mean", "name": "mean"},
            {"value": "median", "name": "median"},
            {"value": "max", "name": "max"},
            {"value": "min", "name": "minimum"},
            {"value": "per90", "name": "90th percentile"},
            {"value": "per95", "name": "95th percentile"},
            {"value": "per99", "name": "99th percentile"}
        ]
    });

    var summ = Ext.create('Ext.form.field.ComboBox', {
        id: this.id + "summ",
        name: "summ",
        fieldLabel: "Summ",
        store: summValues,
        queryMode: 'local',
        displayField: 'name',
        valueField: 'value',
        value: summValues.getAt(4).get('value'),
        labelWidth: 100,
        margin: '5 0 5 5',
        editable: false,
        allowBlank: false
    });

    return Ext.create('Ext.panel.Panel', {
        title: 'Other parameters',
        border: true,
        bodyPadding: "5",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
        layout: 'vbox',
        items: [summ]
    });
};


PathipredPredictionForm.prototype._getPathwaysPanel = function () {
    var checkAll = function (allValue) {
        pathways.items.each(function (item) {
            if (!item.isDisabled()) {
                item.setValue(allValue.value);
            }
        });
    };

    var pathways = Ext.create('Ext.form.CheckboxGroup', {
        // Arrange checkboxes into two columns, distributed vertically
        id: this.id + 'pathways',
        columns: 2,
        vertical: true,
        defaults: {margin: '0 15 0 0'},
        items: [
            { boxLabel: 'PPAR SIGNALING PATHWAY', name: 'pathways', inputValue: '03320' },
            { boxLabel: 'ERBB SIGNALING PATHWAY', name: 'pathways', inputValue: '04012' },
            { boxLabel: 'CALCIUM SIGNALING PATHWAY', name: 'pathways', inputValue: '04020' },
            { boxLabel: 'CYTOKINE-CYTOKINE RECEPTOR', name: 'pathways', inputValue: '04060', id: 'pathways04060' + this.id},
//            { boxLabel: 'CHEMOKINE SIGNALING PATHWAY', name: 'pathways', inputValue: '04062', id: 'pathways04062' + this.id},
            { boxLabel: 'NEUROACTIVE LIGAND-RECEPTOR INTERACTION', name: 'pathways', inputValue: '04080' },
            { boxLabel: 'p53 SIGNALING PATHWAY', name: 'pathways', inputValue: '04115', id: 'pathways04115' + this.id},
            { boxLabel: 'mTOR SIGNALING PATHWAY', name: 'pathways', inputValue: '04150', id: 'pathways04150' + this.id},
            { boxLabel: 'APOPTOSIS', name: 'pathways', inputValue: '04210' },
            { boxLabel: 'WNT SIGNALING PATHWAY', name: 'pathways', inputValue: '04310' },
            { boxLabel: 'NOTCH SIGNALING PATHWAY', name: 'pathways', inputValue: '04330' },
            { boxLabel: 'HEDGEHOG SIGNALING PATHWAY', name: 'pathways', inputValue: '04340', id: 'pathways04340' + this.id},
            { boxLabel: 'VEGF SIGNALING PATHWAY', name: 'pathways', inputValue: '04370' },
            { boxLabel: 'ECM-RECEPTOR INTERACTION', name: 'pathways', inputValue: '04512', id: 'pathways04512' + this.id},
            { boxLabel: 'CELL ADHESION MOLECULES', name: 'pathways', inputValue: '04514' },
            { boxLabel: 'TIGH JUNCTION', name: 'pathways', inputValue: '04530', id: 'pathways04530' + this.id},
            { boxLabel: 'GAP JUNCTION', name: 'pathways', inputValue: '04540' },
            { boxLabel: 'ANTIGEN PROCESING AND PRESENTATION', name: 'pathways', inputValue: '04612' },
            { boxLabel: 'TOLL-LIKE RECEPTOR SIGNALING PATHWAY', name: 'pathways', inputValue: '04620', id: 'pathways04620' + this.id},
            { boxLabel: 'JAK-STAT SIGNALING PATHWAY', name: 'pathways', inputValue: '04630' },
            { boxLabel: 'T CELL RECPTOR SIGNALING PATHWAY', name: 'pathways', inputValue: '04660', id: 'pathways04660' + this.id},
            { boxLabel: 'B CELL RECEPTOR SIGNALING PATHWAY', name: 'pathways', inputValue: '04662' },
            { boxLabel: 'Fc EPSILON RI SIGNALING PATHWAY', name: 'pathways', inputValue: '04664' },
            { boxLabel: 'INSULIN SIGNALING PATHWAY', name: 'pathways', inputValue: '04910' },
            { boxLabel: 'GnRH SIGNALING PATHWAY', name: 'pathways', inputValue: '04912' },
            { boxLabel: 'MELANOGENESIS', name: 'pathways', inputValue: '04916' },
            { boxLabel: 'ADIPOCYTOKINE SIGNALING PATHWAY', name: 'pathways', inputValue: '04920' }
        ]
    });

    return Ext.create('Ext.panel.Panel', {
        title: 'Pathways',
        border: true,
        bodyPadding: "5",
        margin: "0 0 5 0",
        width: "99%",
        buttonAlign: 'center',
        items: [
            {xtype: 'checkboxfield', id: this.id + 'allPathways', name: 'allPathways', boxLabel: 'All', handler: checkAll, margin: '0 0 2 4', inputValue: "Funciona"},
            pathways
        ]
    });
};

PathipredPredictionForm.prototype.loadForm = function (job) {
    var command = job.command.data;
    if (command) {

        var pathToRemove = '/httpd/bioinfo/opencga/accounts/'+$.cookie("bioinfo_account")+'/';
        command['norm-matrix'] = command['norm-matrix'].replace(pathToRemove, '');
        command['exp-design'] = command['exp-design'].replace(pathToRemove, '');

        if (command['norm-matrix'].indexOf('/opencga/analysis/pathiways/examples/') != -1) {
            var arr = command['norm-matrix'].split(/\//g);
            command['norm-matrix'] = 'example_' + arr[arr.length - 1];
        }
        if (command['exp-design'].indexOf('/opencga/analysis/pathiways/examples/') != -1) {
            var arr = command['exp-design'].split(/\//g);
            command['exp-design'] = 'example_' + arr[arr.length - 1];
        }

        Ext.getCmp(this.id + 'norm-matrix').setText('<span class="emph">' + command['norm-matrix'] + '</span>', false);
        Ext.getCmp(this.id + 'norm-matrix' + 'hidden').setValue(command['norm-matrix'].replace(/\//g, ":"));

        Ext.getCmp(this.id + 'exp-design').setText('<span class="emph">' + command['exp-design'] + '</span>', false);
        Ext.getCmp(this.id + 'exp-design' + 'hidden').setValue(command['exp-design'].replace(/\//g, ":"));

        Ext.getCmp(this.id + 'platformRadioGroup').setValue({platform: command['platform']});

        if (command['cel-compressed-file'] == 'true') {
            Ext.getCmp(this.id + 'compressedRadio').setValue(true);
        } else {
            Ext.getCmp(this.id + 'normRadio').setValue(true);
        }


        Ext.getCmp(this.id + 'control').setValue(command['control']);
        Ext.getCmp(this.id + 'disease').setValue(command['disease']);


        Ext.getCmp(this.id + 'summ').select(Ext.getStore(this.id + 'summStore').findRecord('value', command['summ']));


        Ext.getCmp(this.id + 'allPathways').setValue(false);
        /* process pathways */
        var pathways_array = command['pathways'].replace('/ /g', '').split(/,{1}/g);
        for (var i = 0; i < pathways_array.length; i++) {
            var pathway_code = pathways_array[i].substring(3);
            Ext.getCmp(this.id + 'pathways').child('checkboxfield[inputValue=' + pathway_code + ']').setValue(true);
        }

        var species;
        if (pathways_array[0].substring(0, 3) == 'hsa') {
            species = 'hsapiens'
        }
        if (pathways_array[0].substring(0, 3) == 'mmu') {
            species = 'mmusculus'
        }
        Ext.getCmp(this.id + 'speciesRadioGroup').setValue({species: species});
        /* */


        Ext.getCmp(this.id + 'jobname').setValue(command['exp-name']);
        Ext.getCmp(this.id + 'jobdescription').setValue(command['jobdescription']);

        this.paramsWS['bestmodelfile'] = (job.outdir+':svm_bestmodel.RData').replace(/\//g, ":");
        console.log((job.outdir+':svm_bestmodel.RData').replace(/\//g, ":"))
    }

};

